# GalPRIME

***GAL***axy ***P***rofile ***R***ecovery from ***I***mages of ***M***odel ***E***mission

Galprime is a testing suite for images and catalogues of astronomical information, 
using differences between the extracted profiles of a model galaxy and that same model 
added to various backgrounds. 

It is designed to work with any catalogue of structural parameters, as well as any set 
of input images.